%global srcname immutables

%bcond_without  tests

%global common_description %{expand:
An immutable mapping type for Python.

The underlying datastructure is a Hash Array Mapped Trie (HAMT) used in
Clojure, Scala, Haskell, and other functional languages. This implementation is
used in CPython 3.7 in the contextvars module (see PEP 550 and PEP 567 for more
details).

Immutable mappings based on HAMT have O(log N) performance for both set() and
get() operations, which is essentially O(1) for relatively small mappings.}


Name:           python-%{srcname}
Version:        0.19
Release:    1%{?dist}
Summary:        Immutable Collections
License:        Apache-2.0 AND 0BSD
URL:            https://github.com/MagicStack/immutables
Source0:         %pypi_source
Patch0:          0001-Python-3.12-compatibility-105.patch

BuildRequires:  gcc


%description %{common_description}


%package -n python3-%{srcname}
Summary:        %{summary}
BuildRequires:  python3-devel
%if %{with tests}
BuildRequires:  python3-pytest
%endif
BuildRequires:  pythoncapi-compat-static

%description -n python3-%{srcname} %{common_description}


%prep
%autosetup -n %{srcname}-%{version} -p 1

sed -e '/include_package_data=/ s/True/False/' -i setup.py

rm tests/conftest.py tests/test_mypy.py

rm -vf immutables/pythoncapi_compat.h


%generate_buildrequires
%pyproject_buildrequires


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files %{srcname}


%check
%if %{with tests}
%pytest --verbose
%else
%endif


%files -n python3-%{srcname} -f %{pyproject_files}
%doc README.rst


%changelog
* Fri Jun 28 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.19-1
- initial build
